#include "testde.h"
 
#include <QtCore> 
#include "plasma/datacontainer.h"
 
TestDataEngine::TestDataEngine(QObject* parent, const QVariantList& args)
    : Plasma::DataEngine(parent)
{
    // This prevents applets from setting an unnecessarily high
    // update interval and using too much CPU.
    // In the case of a clock that only has second precision,
    // a third of a second should be more than enough.
   setMinimumUpdateInterval(1000);
}

void TestDataEngine::init()
{
   updateSource("MemFree");
   updateSource("Buffers");
}
 
bool TestDataEngine::sourceRequestEvent(const QString &name)
{
    // We do not have any special code to execute the
    // first time a source is requested, so we just call
    // updateSourceEvent().
    return updateSourceEvent(name);
}

bool TestDataEngine::sourceRequested(const QString &name) 
{
   return updateSourceEvent(name);
}

bool TestDataEngine::updateSource(const QString &name) 
{
   return updateSourceEvent(name);
}

bool TestDataEngine::updateSourceEvent(const QString &name)
{
    QFile file("/proc/meminfo");
    file.open(QIODevice::ReadOnly);
    char line[256];
    while(file.readLine(line, 256) != 0) {
      QString s = line;
      if (s.indexOf(name) >= 0) {
	  setData(name, I18N_NOOP("Value"), s);
	  file.close();
	  return true;
      }
    }
    file.close();
    return false;
}
 
// This does the magic that allows Plasma to load
// this plugin.  The first argument must match
// the X-Plasma-EngineName in the .desktop file.
K_EXPORT_PLASMA_DATAENGINE(testde, TestDataEngine)
 
// this is needed since TestDataEngine is a QObject
#include "testde.moc" 
